@@ -27,10 +27,5 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
-from .device import *
-from .local import *
-from .register import *
-from .register_row import *
-from .serial_number import *
 from .auth import *
 from .error import *
